@@ -18,6 +18,6 @@ admin.site.register(Lemma, LemmaAdmin)
 
 class WordFormAdmin(admin.ModelAdmin):
     model = WordForm
-    list_display = ('Label','getSpellings','getTranscriptions')
+    list_display = ('Lemma','getSpellings','getTranscriptions')
 
 admin.site.register(WordForm, WordFormAdmin)
